#[behavior]Expand description
Generate the mechanical Behavior implementation for a normal inherent
impl containing init(&mut self) and receive(&mut self, from, message).
The original impl and methods are preserved unchanged.
#[behavior]Generate the mechanical Behavior implementation for a normal inherent
impl containing init(&mut self) and receive(&mut self, from, message).
The original impl and methods are preserved unchanged.